@@ -245,6 +245,6 @@ except ImportError as e:
         "Dask array requirements are not installed.\n\n"
         "Please either conda or pip install as follows:\n\n"
         "  conda install dask                 # either conda install\n"
-        "  python -m pip install dask[array] --upgrade  # or python -m pip install"
+        '  python -m pip install "dask[array]" --upgrade  # or python -m pip install'
     )
     raise ImportError(str(e) + "\n\n" + msg)
