@@ -199,6 +199,14 @@ def test_rechunk_0d():
     assert y.compute() == a
 
 
+@pytest.mark.parametrize(
+    "arr", [da.array([]), da.array([[], []]), da.array([[[]], [[]]])]
+)
+def test_rechunk_empty_array(arr):
+    arr.rechunk()
+    assert arr.size == 0
+
+
 def test_rechunk_empty():
     x = da.ones((0, 10), chunks=(5, 5))
     y = x.rechunk((2, 2))
@@ -280,9 +288,13 @@ def test_merge_to_number():
     assert chunks == (9,)
 
 
-def _plan(old_chunks, new_chunks, itemsize=1, block_size_limit=1e7):
+def _plan(old_chunks, new_chunks, itemsize=1, block_size_limit=1e7, threshold=4):
     return plan_rechunk(
-        old_chunks, new_chunks, itemsize=itemsize, block_size_limit=block_size_limit
+        old_chunks,
+        new_chunks,
+        itemsize=itemsize,
+        block_size_limit=block_size_limit,
+        threshold=threshold,
     )
 
 
@@ -314,6 +326,8 @@ def test_plan_rechunk():
     _assert_steps(steps, [(c, c)])
     steps = _plan((f, c), (c, c))
     _assert_steps(steps, [(c, c)])
+    steps = _plan((c, c, c, c), (c, f, c, c))
+    _assert_steps(steps, [(c, f, c, c)])
 
     # An intermediate is used to reduce graph size
     steps = _plan((f, c), (c, f))
@@ -326,6 +340,10 @@ def test_plan_rechunk():
     steps = _plan((nc + nf, c + c, c + f), (nc + nf, f + f, c + c))
     _assert_steps(steps, steps)
 
+    # Regression test for #5908
+    steps = _plan((c, c), (f, f), threshold=1)
+    _assert_steps(steps, [(f, f)])
+
     # Just at the memory limit => an intermediate is used
     steps = _plan((f, c), (c, f), block_size_limit=400)
     _assert_steps(steps, [(c, c), (c, f)])
@@ -626,6 +644,12 @@ def test_rechunk_zero_dim():
     assert len(x.compute()) == 0
 
 
+def test_rechunk_empty_chunks():
+    x = da.zeros((7, 24), chunks=((7,), (10, 0, 0, 9, 0, 5)))
+    y = x.rechunk((2, 3))
+    assert_eq(x, y)
+
+
 def test_rechunk_avoid_needless_chunking():
     x = da.ones(16, chunks=2)
     y = x.rechunk(8)
