@@ -51,6 +51,6 @@ except ImportError as e:
         "Dask dataframe requirements are not installed.\n\n"
         "Please either conda or pip install as follows:\n\n"
         "  conda install dask                     # either conda install\n"
-        "  python -m pip install dask[dataframe] --upgrade  # or python -m pip install"
+        '  python -m pip install "dask[dataframe]" --upgrade  # or python -m pip install'
     )
     raise ImportError(msg) from e
