@@ -153,7 +153,10 @@ def describe_numeric_aggregate(stats, name=None, is_timedelta_col=False):
     assert len(stats) == 6
     count, mean, std, min, q, max = stats
 
-    typ = pd.DataFrame if isinstance(count, pd.Series) else pd.Series
+    if is_series_like(count):
+        typ = type(count.to_frame())
+    else:
+        typ = type(q)
 
     if is_timedelta_col:
         mean = pd.to_timedelta(mean)
@@ -163,14 +166,15 @@ def describe_numeric_aggregate(stats, name=None, is_timedelta_col=False):
         q = q.apply(lambda x: pd.to_timedelta(x))
 
     part1 = typ([count, mean, std, min], index=["count", "mean", "std", "min"])
+
     q.index = ["{0:g}%".format(l * 100) for l in q.index.tolist()]
-    if isinstance(q, pd.Series) and typ == pd.DataFrame:
+    if is_series_like(q) and typ != type(q):
         q = q.to_frame()
     part3 = typ([max], index=["max"])
 
-    result = pd.concat([part1, q, part3], sort=False)
+    result = concat([part1, q, part3], sort=False)
 
-    if isinstance(result, pd.Series):
+    if is_series_like(result):
         result.name = name
 
     return result
@@ -351,7 +355,13 @@ concat_dispatch = Dispatch("concat")
 
 
 def concat(
-    dfs, axis=0, join="outer", uniform=False, filter_warning=True, ignore_index=False
+    dfs,
+    axis=0,
+    join="outer",
+    uniform=False,
+    filter_warning=True,
+    ignore_index=False,
+    **kwargs
 ):
     """Concatenate, handling some edge cases:
 
@@ -382,15 +392,22 @@ def concat(
             uniform=uniform,
             filter_warning=filter_warning,
             ignore_index=ignore_index,
+            **kwargs
         )
 
 
 @concat_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
 def concat_pandas(
-    dfs, axis=0, join="outer", uniform=False, filter_warning=True, ignore_index=False
+    dfs,
+    axis=0,
+    join="outer",
+    uniform=False,
+    filter_warning=True,
+    ignore_index=False,
+    **kwargs
 ):
     if axis == 1:
-        return pd.concat(dfs, axis=axis, join=join, sort=False)
+        return pd.concat(dfs, axis=axis, join=join, **kwargs)
 
     # Support concatenating indices along axis 0
     if isinstance(dfs[0], pd.Index):
@@ -461,7 +478,7 @@ def concat_pandas(
                 cat_mask = pd.concat(
                     [(df.dtypes == "category").to_frame().T for df in dfs3],
                     join=join,
-                    sort=False,
+                    **kwargs
                 ).any()
 
         if cat_mask.any():
@@ -470,7 +487,7 @@ def concat_pandas(
             out = pd.concat(
                 [df[df.columns.intersection(not_cat)] for df in dfs3],
                 join=join,
-                sort=False,
+                **kwargs
             )
             temp_ind = out.index
             for col in cat_mask.index.difference(not_cat):
@@ -511,7 +528,8 @@ def concat_pandas(
         with warnings.catch_warnings():
             if filter_warning:
                 warnings.simplefilter("ignore", FutureWarning)
-            out = pd.concat(dfs2, join=join, sort=False)
+
+            out = pd.concat(dfs2, join=join, **kwargs)
     # Re-add the index if needed
     if ind is not None:
         out.index = ind
